# Тетрис
## Описание проекта:
### Многопользовательская игра ТЕТРИС обладающая 'ламповым' дизайном и стилистикой ретро-футуризма
## Зависимости:
### 1 - python 3  
### 2 - django 4.0.2 
### 3 - Pillow
### 4 - sqlparse 0.4.2
### 5 - django-watchman 
### 6 - decorator
### 7 - cms 0.0.2
### 8 - self 2020.12.3
## Команда для запуска:
### 1 - python manage.py runserver

